Apply .clangformat to all repo source files
Change-Id: I7e79c6058f0303f9a98911e3b7dd2e8596079344
This commit is contained in:
@@ -17,11 +17,10 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
||||
THE SOFTWARE.
|
||||
*/
|
||||
|
||||
#include<hip/hip_runtime_api.h>
|
||||
#include"test_common.h"
|
||||
#include <hip/hip_runtime_api.h>
|
||||
#include "test_common.h"
|
||||
|
||||
int main()
|
||||
{
|
||||
int main() {
|
||||
int dev;
|
||||
hipDeviceProp_t prop;
|
||||
HIP_PRINT_STATUS(hipChooseDevice(&dev, &prop));
|
||||
|
||||
@@ -17,13 +17,13 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
||||
THE SOFTWARE.
|
||||
*/
|
||||
|
||||
#include<hip/hip_runtime_api.h>
|
||||
#include"test_common.h"
|
||||
#include <hip/hip_runtime_api.h>
|
||||
#include "test_common.h"
|
||||
|
||||
int main()
|
||||
{
|
||||
int main() {
|
||||
int val;
|
||||
hipDeviceAttribute_t attr = hipDeviceAttributeMaxThreadsPerBlock; ///< Maximum number of threads per block.
|
||||
hipDeviceAttribute_t attr =
|
||||
hipDeviceAttributeMaxThreadsPerBlock; ///< Maximum number of threads per block.
|
||||
|
||||
HIP_PRINT_STATUS(hipDeviceGetAttribute(NULL, attr, 0));
|
||||
HIP_PRINT_STATUS(hipDeviceGetAttribute(&val, attr, 0));
|
||||
@@ -35,5 +35,4 @@ int main()
|
||||
HIP_PRINT_STATUS(hipDeviceGetAttribute(&val, attr, 0));
|
||||
HIP_PRINT_STATUS(hipDeviceGetAttribute(NULL, attr, -1));
|
||||
HIP_PRINT_STATUS(hipDeviceGetAttribute(&val, attr, -1));
|
||||
|
||||
}
|
||||
|
||||
@@ -17,11 +17,10 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
||||
THE SOFTWARE.
|
||||
*/
|
||||
|
||||
#include<hip/hip_runtime_api.h>
|
||||
#include"test_common.h"
|
||||
#include <hip/hip_runtime_api.h>
|
||||
#include "test_common.h"
|
||||
|
||||
int main()
|
||||
{
|
||||
int main() {
|
||||
hipFuncCache_t pCacheConfig;
|
||||
HIP_PRINT_STATUS(hipDeviceGetCacheConfig(&pCacheConfig));
|
||||
HIP_PRINT_STATUS(hipDeviceGetCacheConfig(NULL));
|
||||
|
||||
@@ -20,8 +20,7 @@ THE SOFTWARE.
|
||||
#include <hip/hip_runtime_api.h>
|
||||
#include "test_common.h"
|
||||
|
||||
int main()
|
||||
{
|
||||
int main() {
|
||||
hipLimit_t lim = hipLimitMallocHeapSize;
|
||||
HIP_PRINT_STATUS(hipDeviceGetLimit(NULL, lim));
|
||||
}
|
||||
|
||||
@@ -17,11 +17,10 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
||||
THE SOFTWARE.
|
||||
*/
|
||||
|
||||
#include<hip/hip_runtime_api.h>
|
||||
#include"test_common.h"
|
||||
#include <hip/hip_runtime_api.h>
|
||||
#include "test_common.h"
|
||||
|
||||
int main()
|
||||
{
|
||||
int main() {
|
||||
hipSharedMemConfig_t config;
|
||||
HIP_PRINT_STATUS(hipDeviceGetSharedMemConfig(NULL));
|
||||
HIP_PRINT_STATUS(hipDeviceGetSharedMemConfig(&config));
|
||||
|
||||
@@ -20,8 +20,7 @@ THE SOFTWARE.
|
||||
#include <hip/hip_runtime_api.h>
|
||||
#include "test_common.h"
|
||||
|
||||
int main()
|
||||
{
|
||||
int main() {
|
||||
HIP_PRINT_STATUS(hipGetDevice(NULL));
|
||||
HIP_PRINT_STATUS(hipGetDevice(0));
|
||||
}
|
||||
|
||||
@@ -20,7 +20,4 @@ THE SOFTWARE.
|
||||
#include <hip/hip_runtime_api.h>
|
||||
#include "test_common.h"
|
||||
|
||||
int main()
|
||||
{
|
||||
HIP_PRINT_STATUS(hipGetDeviceCount(NULL));
|
||||
}
|
||||
int main() { HIP_PRINT_STATUS(hipGetDeviceCount(NULL)); }
|
||||
|
||||
@@ -20,12 +20,11 @@ THE SOFTWARE.
|
||||
#include <hip/hip_runtime_api.h>
|
||||
#include "test_common.h"
|
||||
|
||||
int main()
|
||||
{
|
||||
int main() {
|
||||
hipDeviceProp_t prop;
|
||||
HIP_PRINT_STATUS(hipGetDeviceProperties(&prop, -1));
|
||||
int cnt;
|
||||
hipGetDeviceCount(&cnt);
|
||||
HIP_PRINT_STATUS(hipGetDeviceProperties(&prop, cnt+1));
|
||||
HIP_PRINT_STATUS(hipGetDeviceProperties(&prop, cnt + 1));
|
||||
HIP_PRINT_STATUS(hipGetDeviceProperties(NULL, 0));
|
||||
}
|
||||
|
||||
@@ -20,10 +20,9 @@ THE SOFTWARE.
|
||||
#include <hip/hip_runtime_api.h>
|
||||
#include "test_common.h"
|
||||
|
||||
int main()
|
||||
{
|
||||
int main() {
|
||||
HIP_PRINT_STATUS(hipSetDevice(-1));
|
||||
int count;
|
||||
hipGetDeviceCount(&count);
|
||||
HIP_PRINT_STATUS(hipSetDevice(count+1));
|
||||
HIP_PRINT_STATUS(hipSetDevice(count + 1));
|
||||
}
|
||||
|
||||
@@ -20,8 +20,7 @@ THE SOFTWARE.
|
||||
#include <hip/hip_runtime_api.h>
|
||||
#include "test_common.h"
|
||||
|
||||
int main()
|
||||
{
|
||||
int main() {
|
||||
HIP_PRINT_STATUS(hipSetDeviceFlags(-1));
|
||||
HIP_PRINT_STATUS(hipSetDeviceFlags(11));
|
||||
}
|
||||
|
||||
Reference in New Issue
Block a user